@@ -15,14 +15,25 @@ __all__ = [
     'tasks',
     'utils',
     'exceptions',
-    'SwitchGuideTask'
+    'SwitchGuideTask',
+    'api',
+    'step',
+    'guide',
+    'literals',
+    'enums'
 ]
 
 from . import models
+from .models import api
+from .models import step
+from .models import guide
+from .models import enums
+from .models import literals
+
 from . import exceptions
 from . import tasks
 from . import exceptions
 from . import utils
 from .SwitchGuideTask import SwitchGuideTask
 
-__version__ = "0.1.13"
+__version__ = "0.1.14"
